from django.db import models


class License(models.Model):
    name = models.CharField(max_length=80, unique=True)
    symbols = models.CharField(max_length=5)
    url = models.URLField(unique=True)

    def __unicode__(self):
        return self.name

    def get_absolute_url(self):
        return self.url

class Licensed(models.Model):
    license = models.ForeignKey(License)
    class Meta:
        abstract = True





DEBUG=True

DATABASES={
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
    }
}

SECRET_KEY = 'secret'

INSTALLED_APPS=(
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.admin',
    'licensing',
    'tests',
)



import os
from setuptools import setup

README = open(os.path.join(os.path.dirname(__file__), 'README.rst')).read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-licensing',
    version='1.0.0',
    packages=['licensing'],
    include_package_data=True,
    license='Public Domain',
    description='A Django model and data for adding licensing info to data.',
    long_description=README,
    url='http://github.com/editorsnotes/django-licensing',
    download_url='http://github.com/editorsnotes/django-licensing/tarball/1.0.0',
    author='Ryan Shaw',
    author_email='ryanshaw@unc.edu',
    keywords = ['django', 'licenses', 'licences'],
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: Public Domain',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)
